@@ -608,14 +608,23 @@ def parse_bss_list_and_print(wireless_network_bss_list, args, **kwargs):
         if args.apnames or args.ethers:
             out_results[-1].append(bss.apname.out())
 
+    def get_index(key):
+        for r in out_results:
+            for i, x in enumerate(r):
+                if key in str(x.header):
+                    return i
+        return -1
+
     if args.uptime:  # sort by uptime
         out_results = sorted(
-            out_results, key=lambda x: int(x[9].value.split("d")[0]), reverse=False
+            out_results,
+            key=lambda x: int(x[get_index("UPTIME")].value.split("d")[0]),
+            reverse=False,
+        )
+    else:  # sort by RSSI
+        out_results = sorted(
+            out_results, key=lambda x: x[get_index("RSSI")].value, reverse=False
         )
-    elif args.apnames or args.ethers:  # sort by RSSI
-        out_results = sorted(out_results, key=lambda x: x[3].value, reverse=False)
-    else:
-        out_results = sorted(out_results, key=lambda x: x[2].value, reverse=False)
 
     # here because i added the verbose, byte file func and export func to this func
     if args.ies or args.bytes or args.export:
@@ -633,7 +642,7 @@ def parse_bss_list_and_print(wireless_network_bss_list, args, **kwargs):
         headers = []
         subheaders = []
 
-        # check for substring that indicates interface is connected to a BSSID in results
+        # check for substring that indicates the scanning interface is also connected to a BSSID found in results
         for row in out_results:
             for data in row:
                 if "(*)" in str(data):
@@ -699,12 +708,11 @@ def parse_bss_list_and_print(wireless_network_bss_list, args, **kwargs):
         else:
             print(json.dumps(json_out))
 
-    # TODO: needs a test to verify this actually does what it should. ALERT the user of dup MACs
     duplicates = set([x for x in bssid_list if bssid_list.count(x) > 1])
     if duplicates:
-        log.warning("***DUPLICATE MACS***")
+        log.warning("***BSSIDS WITH DUPLICATE MACs***")
         log.warning(duplicates)
-        log.warning("***DUPLICATE MACS***")
+        log.warning("***BSSIDS WITH DUPLICATE MACs***")
 
     if args.apnames:
         if stored_ack:
